The HentaiVerse

23295
1083
1272
230
Items
Use various consumable items that can replenish your vitals or augment your power in various ways.

The effect Searing Skin on Yo Yo Yo Wassup Bromie has expired.
The effect Stunned on Yo Yo Yo Wassup Bromie has expired.
Replenishment restores 11 points of magic.
Regen restores 1451 points of health.
Victor Wembanyama gains the effect Searing Skin.
Your spike shield hits Victor Wembanyama for 5 points of fire damage.
You counter Victor Wembanyama for 6000 points of void damage.
Victor Wembanyama uses Block I. You block the attack.
You evade the attack from Arya Stark.
Mikuru Asahina gains the effect Penetrated Armor.
Void Strike hits Mikuru Asahina for 6081 void damage.
Elec Strike hits Mikuru Asahina for 4126 elec damage.
You hit Mikuru Asahina for 9793 void damage.

Flee
Scan
Shield Bash | Vital Strike | Merciful Blow

Fiery Blast | Inferno
Freeze | Blizzard
Shockblast | Chained Lightning
Gale | Downburst
Smite | Banishment
Corruption | Disintegrate
Drain | Weaken | Imperil
Slow | Sleep | Confuse
Blind | Silence | MagNet
Cure | Regen | Full-Cure
Protection | Haste | Shadow Veil
Absorb | Spark of Life | Spirit Shield
Heartseeker | Arcane Focus

P
Spirit Gem
1
Health Draught
2
Health Potion
3
Health Elixir
4
Mana Draught
5
Mana Potion
6
Mana Elixir
7
Spirit Draught
8
Spirit Potion
9
Spirit Elixir
10
11
12
13
14
15
S1
S2
S3
S4
S5
S6
N1
N2
N3
N4
N5
N6
370
Yo Yo Yo Wassup Bromie
370
Arya Stark
370
Space Elevator
370
Victor Wembanyama
370
Mikuru Asahina